@@ -5,29 +5,30 @@
 #' should be assigned.
 #'
 #' @return
-#' \code{x \%<-\% value} (a future assignment) and
-#' \code{futureAssign("x", value)} create a \link{Future} that evaluates
-#' expression \code{expr} and binds its value (as a \link[base]{promise}) to
-#' a variable \code{x}.  The value of the future is automatically retrieved
+#' `x %<-% value` (a future assignment) and
+#' `futureAssign("x", value)` create a [Future] that evaluates
+#' expression `expr` and binds its value (as a
+#' \link[base:delayedAssign]{promise}) to
+#' a variable `x`.  The value of the future is automatically retrieved
 #' when the assigned variable (promise) is queried.
 #' The future itself is returned invisibly, e.g.
-#' \code{f <- futureAssign("x", expr)} and \code{f <- (x \%<-\% expr)}.
-#' Alternatively, the future of a future variable \code{x} can be retrieved
+#' `f <- futureAssign("x", expr)` and `f <- (x %<-% expr)`.
+#' Alternatively, the future of a future variable `x` can be retrieved
 #' without blocking using \code{f <- \link{futureOf}(x)}.
 #' Both the future and the variable (promise) are assigned to environment
-#' \code{assign.env} where the name of the future is \code{.future_<name>}.
+#' `assign.env` where the name of the future is `.future_<name>`.
 #'
 #' @rdname future
 #' @export
-futureAssign <- function(x, value, envir = parent.frame(), substitute = TRUE, lazy = NA, seed = NULL, globals = TRUE, ..., assign.env = envir) {
-  stopifnot(is.character(x), !is.na(x), nzchar(x))
+futureAssign <- function(x, value, envir = parent.frame(), substitute = TRUE, lazy = FALSE, seed = FALSE, globals = TRUE, packages = NULL, stdout = TRUE, conditions = "condition", earlySignal = FALSE, label = NULL, gc = FALSE, ..., assign.env = envir) {
+  stop_if_not(is.character(x), !is.na(x), nzchar(x))
   if (substitute) value <- substitute(value)
 
 
   ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   ## (1) Arguments passed to future()
   ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  future.args <- list(value, envir = envir, lazy = lazy, seed = seed, globals = globals, ...)
+  future.args <- list(value, envir = envir, lazy = lazy, seed = seed, globals = globals, packages = packages, stdout = stdout, conditions = conditions, earlySignal = earlySignal, label = label, gc = gc, ...)
 
   ## Any arguments set via disposible option?
   args <- getOption("future.disposable", NULL)
@@ -36,11 +37,6 @@ futureAssign <- function(x, value, envir = parent.frame(), substitute = TRUE, la
     on.exit(options(future.disposable = NULL))
   }
 
-  ## BACKWARD COMPATIBILITY: So that plan(lazy) still works
-  ## TODO: Remove when lazy() is removed.
-  lazy <- future.args$lazy
-  if (is.logical(lazy) && is.na(lazy)) future.args$lazy <- NULL
-
 
   ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   ## (2) Create future
